Module types

Module types 

Structs

Git
Encapsulate the git repository struct to set it as optional and add top level convenience methods for easier querying.
HookIter
An iterator over the variants of Hook
SpecialIter
An iterator over the variants of Special

Enums

Flag
An enumaration over the different types of flags(actions) that can trigger a pipeline run.
Hook
An enumaration over the different types of git-hooks(sub-flags) that can trigger a pipeline run.
Special
An enumaration over the different types of special flags(sub-flags) that are external to git and involves other triggering methods and that can trigger a pipeline run.