pub struct Git {
pub repo: Option<Repository>,
}Expand description
Encapsulate the git repository struct to set it as optional and add top level convenience methods for easier querying.
Fields
repo: Option<Repository>Implementations
Sourceimpl Git
impl Git