Module types
pipelight_
utils
0.2.9
Module types
Module Items
Structs
Enums
In pipelight_
utils::
git
pipelight_utils
::
git
Module
types
Structs

Git
Encapsulate the git repository struct to set it as optional and add top level convenience methods for easier querying.
Hook
Iter
An iterator over the variants of
Hook
Special
Iter
An iterator over the variants of
Special
Enums

Flag
An enumaration over the different types of flags(actions) that can trigger a pipeline run.
Hook
An enumaration over the different types of git-hooks(sub-flags) that can trigger a pipeline run.
Special
An enumaration over the different types of special flags(sub-flags) that are external to git and involves other triggering methods and that can trigger a pipeline run.